@@ -170,7 +170,7 @@ class PlotMax:
             ysize: the font size of the scale of y axis
             title: the title of subfigure
             xtype: abandoned, the type of x axis, time, numeric, what else...
-            plot_type: 'curve', 'bar', 'hist', '曲线', '直方图'
+            plot_type: 'curve', 'bar', 'hist', '曲线', '直方图', 'scatter'
             legend: whether to show the label
             legendsize: the font size of legend
             y2: data list of second y axis
@@ -445,7 +445,7 @@ class PlotMax:
                 count = 0
                 self.subplot_index += 1
                 if d['legend']:
-                    legend_font = fm.FontProperties(fname=FNAME, size=d['legendsize'])
+                    legend_font = fm.FontProperties(fname=self.fname, size=d['legendsize'])
                     ax.legend(handles, labels, fontsize=d['legendsize'], loc=legend_loc, \
                               markerscale=d['markerscale'], shadow=True, bbox_to_anchor=anchor,\
                               prop=legend_font)
